cameraModeActiveBackgroundColor property
Background color for the camera mode button when camera is active.
Implementation
final Color? cameraModeActiveBackgroundColor;
Background color for the camera mode button when camera is active.
final Color? cameraModeActiveBackgroundColor;