cameraModeInactiveIconColor property
Icon color for the camera mode button when in search mode (inactive).
Implementation
final Color? cameraModeInactiveIconColor;
Icon color for the camera mode button when in search mode (inactive).
final Color? cameraModeInactiveIconColor;